@@ -18,7 +18,7 @@ import ToyModule
 struct Main {
   static func main() {
     let value = ToyValue(number: 10)
-    print(value.hexString)
+    print(value.stringValue)
     print(value.squared())
   }
 }
