@@ -116,6 +116,15 @@ SwiftRunner::SwiftRunner(const std::vector<std::string> &args,
 }
 
 int SwiftRunner::Run(std::ostream *stderr_stream, bool stdout_to_stderr) {
+  // In rules_swift < 3.x the .swiftsourceinfo files are unconditionally written to the module path.
+  // In rules_swift >= 3.x these same files are no longer tracked by Bazel unless explicitly requested.
+  // When using non-sandboxed mode, previous builds will contain these files and cause build failures
+  // when Swift tries to use them, in order to work around this compatibility issue, we check the module path for
+  // the presence of .swiftsourceinfo files and if they are present but not requested, we remove them.
+  if (swift_source_info_path_ != "" && !emit_swift_source_info_) {
+    std::filesystem::remove(swift_source_info_path_);
+  }
+
   int exit_code = RunSubProcess(
       args_, &job_env_, stderr_stream, stdout_to_stderr);
 
@@ -392,6 +401,8 @@ std::vector<std::string> SwiftRunner::ParseArguments(Iterator itr) {
         target_label_ = arg;
       } else if (arg == "-file-prefix-pwd-is-dot") {
         file_prefix_pwd_is_dot_ = true;
+      } else if (arg == "-emit-swiftsourceinfo") {
+        emit_swift_source_info_ = true;
       }
     } else {
       if (arg == "-output-file-map") {
@@ -406,6 +417,12 @@ std::vector<std::string> SwiftRunner::ParseArguments(Iterator itr) {
         out_args.push_back(arg);
       } else if (arg == "-dump-ast") {
         is_dump_ast_ = true;
+      } else if (arg == "-emit-module-path") {
+        ++it;
+        arg = *it;
+        std::filesystem::path module_path(arg);
+        swift_source_info_path_ = module_path.replace_extension(".swiftsourceinfo").string();
+        out_args.push_back(arg);
       }
     }
   }
