@@ -47,6 +47,12 @@ extern bool ArgumentEnablesWMO(const std::string &arg);
 //     applied here because we do not know the current working directory at
 //     analysis time when the argument list is constructed.
 //
+// -Xwrapped-swift=-file-prefix-pwd-is-dot
+//     When specified, the Swift compiler will be directed to remap the current
+//     directory's path to the string "." in debug, coverage, and index info.
+//     This remapping must be applied here because we do not know the current
+//     working directory at analysis time when the argument list is constructed.
+//
 // -Xwrapped-swift=-ephemeral-module-cache
 //     When specified, the spawner will create a new temporary directory, pass
 //     that to the Swift compiler using `-module-cache-path`, and then delete
@@ -170,6 +176,12 @@ class SwiftRunner {
   // `-index-store-path`. After running `swiftc` `index-import` copies relevant
   // index outputs into the `index_store_path` to integrate outputs with Bazel.
   std::string global_index_store_import_path_;
+
+  // The path where the module files will be written
+  std::string swift_source_info_path_;
+
+  // Whether `.swiftsourceinfo` files are being generated.
+  bool emit_swift_source_info_;
 };
 
 #endif  // BUILD_BAZEL_RULES_SWIFT_TOOLS_WORKER_SWIFT_RUNNER_H_
